==> atlassian-whitelist-api-plugin-1.6-sources.jar: com/atlassian/plugins/whitelist/ImmutableWhitelistRule.java <==
package com.atlassian.plugins.whitelist;

import com.atlassian.annotations.PublicApi;
import com.google.common.base.Objects;

import javax.annotation.concurrent.Immutable;

import static com.google.common.base.Preconditions.checkNotNull;

/**
 * @since 1.0
 */
@Immutable
@PublicApi
public final class ImmutableWhitelistRule implements WhitelistRule
{
    private final Integer id;
    private final String expression;
    private final WhitelistType type;
    private final boolean allowInbound;

    public ImmutableWhitelistRule(final ImmutableWhitelistRuleBuilder builder)
    {
        checkNotNull(builder, "builder");
        this.id = builder.id;
        this.expression = checkNotNull(builder.expression, "expression");
        this.type = checkNotNull(builder.type, "type");
        this.allowInbound = builder.allowInbound;
    }

    public static ImmutableWhitelistRuleBuilder builder()
    {
        return new ImmutableWhitelistRuleBuilder();
    }

    @Override
    public Integer getId()
    {
        return id;
    }

    @Override
    public String getExpression()
    {
        return expression;
    }

    @Override
    public WhitelistType getType()
    {
        return type;
    }

    @Override
    public boolean isAllowInbound()
    {
        return allowInbound;
    }

    @Override
    public boolean equals(Object o)
    {
        if (this == o)
        {
            return true;
        }
        if (o == null || getClass() != o.getClass())
        {
            return false;
        }

        final ImmutableWhitelistRule that = (ImmutableWhitelistRule) o;
        return Objects.equal(id, that.id) &&
                Objects.equal(expression, that.expression) &&
                Objects.equal(type, that.type) &&
                Objects.equal(allowInbound, that.allowInbound);
    }

    @Override
    public int hashCode()
    {
        return Objects.hashCode(id, expression, type, allowInbound);
    }

    @Override
    public String toString()
    {
        return "ImmutableWhitelistRule{id=" + id + ", expression='" + expression + '\'' + ", type=" + type + ", allowInbound=" + allowInbound + '}';
    }
}

==> atlassian-whitelist-api-plugin-3.0.2-sources.jar: com/atlassian/plugins/whitelist/ImmutableWhitelistRule.java <==
package com.atlassian.plugins.whitelist;

import java.io.Serializable;

import javax.annotation.concurrent.Immutable;

import com.atlassian.annotations.PublicApi;

import com.google.common.base.Objects;

import static com.google.common.base.Preconditions.checkNotNull;

/**
 * @since 1.0
 */
@Immutable
@PublicApi
public final class ImmutableWhitelistRule implements WhitelistRule, Serializable
{
    private final Integer id;
    private final String expression;
    private final WhitelistType type;
    private final boolean allowInbound;

    public ImmutableWhitelistRule(final ImmutableWhitelistRuleBuilder builder)
    {
        checkNotNull(builder, "builder");
        this.id = builder.id;
        this.expression = checkNotNull(builder.expression, "expression");
        this.type = checkNotNull(builder.type, "type");
        this.allowInbound = builder.allowInbound;
    }

    public static ImmutableWhitelistRuleBuilder builder()
    {
        return new ImmutableWhitelistRuleBuilder();
    }

    @Override
    public Integer getId()
    {
        return id;
    }

    @Override
    public String getExpression()
    {
        return expression;
    }

    @Override
    public WhitelistType getType()
    {
        return type;
    }

    @Override
    public boolean isAllowInbound()
    {
        return allowInbound;
    }

    @Override
    public boolean equals(Object o)
    {
        if (this == o)
        {
            return true;
        }
        if (o == null || getClass() != o.getClass())
        {
            return false;
        }

        final ImmutableWhitelistRule that = (ImmutableWhitelistRule) o;
        return Objects.equal(id, that.id) &&
                Objects.equal(expression, that.expression) &&
                Objects.equal(type, that.type) &&
                Objects.equal(allowInbound, that.allowInbound);
    }

    @Override
    public int hashCode()
    {
        return Objects.hashCode(id, expression, type, allowInbound);
    }

    @Override
    public String toString()
    {
        return "ImmutableWhitelistRule{id=" + id + ", expression='" + expression + '\'' + ", type=" + type + ", allowInbound=" + allowInbound + '}';
    }
}
